<?php

namespace Drupal\user_referral_domain\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\user_referral\Plugin\Derivative\ReferralLinkDeriver;

/**
 * Provides refererral link extra field definitions for every referral type.
 *
 * @internal
 *   Plugin derivers are internal.
 */
class ReferralLinkForDomainDeriver extends ReferralLinkDeriver {

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $domains = \Drupal::entityTypeManager()
      ->getStorage('domain')
      ->loadByProperties(['status' => TRUE]);
    foreach ($domains as $domain) {
      $user_referral_types = UserReferralType::loadMultiple();
      foreach ($user_referral_types as $type_id => $referral_type) {
        $derivative = $base_plugin_definition;
        $derivative['label'] = t('@type referral link for @domain domain', ['@type' => $referral_type->label(), '@domain' => $domain->get('name')]);
        $derivative_id = 'user_referral_link' . PluginBase::DERIVATIVE_SEPARATOR . $type_id . PluginBase::DERIVATIVE_SEPARATOR . $domain->getDomainId();
        $derivative['id'] = $derivative_id;
        $this->derivatives[$derivative_id] = $derivative;
      }
    }
    return $this->derivatives;
  }

}
