<?php

namespace Drupal\user_referral\Access;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the custom access control handler for the user accounts.
 */
class UserReferralAccess {

  /**
   * Check whether the user can view referral link list.
   *
   * @param \Drupal\Core\Session\AccountInterface $user
   *   Run access checks for this account.
   *
   * @return \Drupal\Core\Access\AccessResultInterface
   *   The access result.
   */
  public static function checkUserReferrralLinksListAccess(AccountInterface $user) {
    // return AccessResult::allowedIf(TRUE);
    $current_user = \Drupal::currentUser();
    $condition = ($current_user->hasPermission('view any referral link listing'))
      || ($current_user->hasPermission('view own referral link listing') && $current_user->id() === $user->id());
    return AccessResult::allowedIf($condition)->cachePerPermissions();
  }

}
