<?php

namespace Drupal\user_referral\Controller;


use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpFoundation\Request;
use Drupal\user_referral\Entity\UserReferralType;
use Drupal\user\Entity\User;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\user\UserInterface;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;

use Drupal\user_referral\ReferralRedirectResponse;
use Drupal\Core\Url;

/**
 * Controller routines for user referral routes.
 */
class UserReferralController extends ControllerBase {

  /**
   * Redirects to the user password reset form.
   *
   * In order to never disclose a reset link via a referrer header this
   * controller must always return a redirect response.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The request.
   * @param int $uid
   *   User ID of the user requesting reset.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect response.
   */
  public function referralLinkProcess(Request $request, $uid, $type) {
    $account = User::load($uid);

    $referral_type = UserReferralType::load(str_replace('-', '_', $type));
    if ($referral_type) {
      $referral_type->setCookie($account, $request);
      return new ReferralRedirectResponse($referral_type->getGotoPath());
    }
    else {
      throw new NotFoundHttpException();
    }

  }

  /**
   * Lists all referral links for a user.
   */
  public function referralLinksList(Request $request, UserInterface $user) {
    $header = [
      $this->t('Link'),
      $this->t('Type'),
      $this->t('Operations'),
    ];

    $user = \Drupal::currentUser();

    $referral_types = UserReferralType::loadMultiple();
    foreach ($referral_types as $referral_type) {
      if ($referral_type->isApplicable($user)) {
        $rows = [];
        $canonical = '/user/' . $user->id() . '/user-referral/' . str_replace('_', '-', $referral_type->id());
        $rows[] = [
          $canonical,
          $this->t('Canonical'),
          '',
        ];
        $aliases = \Drupal::entityTypeManager()
          ->getStorage('path_alias')
          ->loadByProperties(['path' => $canonical]);
        foreach ($aliases as $alias) {
          if ($user->hasPermission('administer referral links listing of any user')) {
            $operations = [
              '#type' => 'operations',
              '#links' => [
                'delete' => [
                  'title' => $this->t('Delete'),
                  'url' => Url::fromRoute('user_referral.referral_link_alias_delete', ['user' => $user->id(), 'alias' => $alias->id()]),
                ],
              ],
              '#cache' => [
                'tags' => $alias->getCacheTags(),
              ],
            ];
          }
          else {
            $operations = '';
          }

          $rows[] = [
            $alias->getAlias(),
            $this->t('Alias'),
            [ 'data' => $operations,],
          ];
        }
        $output['tables'][$referral_type->id()] = [
          '#type' => 'table',
          '#caption' => $this->t('Type: @type', ['@type' => $referral_type->label()]),
          '#header' => $header,
          '#rows' => $rows,
        ];
      }
    }

    return $output;
  }

  /**
   * Lists all referral links for a user.
   */
  public function referralLinksListTitle(Request $request, UserInterface $user) {
    return $user->label();
  }
}
