<?php

namespace Drupal\user_referral\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\path_alias\Entity\PathAlias;

/**
 * Defines a confirmation form to confirm deletion of a referral link alias.
 */
class ReferrelLinkAliasDeleteForm extends ConfirmFormBase {

  /**
   * Alias to delete.
   *
   * @var int
   */
  protected $alias;

  protected $uid;
  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, string $user = NULL, string $alias = NULL) {
    $this->uid = $user;
    $this->alias = $alias;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    PathAlias::load($this->alias)->delete();
    $form_state->setRedirectUrl($this->getCancelUrl());
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() : string {
    return "user_referral_referral_link_alias_delete_form";
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return Url::fromRoute('user_referral.referral_links_list', ['user' => $this->uid]);
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    $alias = PathAlias::load($this->alias);
    return t('Do you want to delete the referral link alias %alias?', ['%alias' => $alias->getAlias()]);
  }

}