<?php

namespace Drupal\user_referral\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Displays the captcha settings form.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['user_referral.settings'];
  }

  /**
   * Implements \Drupal\Core\Form\FormInterface::getFormID().
   */
  public function getFormId() {
    return 'user_referral_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('user_referral.settings');

    $form['allow_to_change_referral_type'] = array(
      '#type' => 'checkbox',
      '#title' => t('Allow cookie to be reassigned to new Referrers upon subsequent future visits with a URL of different referral type'),
      '#default_value' => $config->get('allow_to_change_referral_type'),
      '#description' => t('<p>The site can have more than one referral type. You may allow to change referral type if user revists with differnet referral link type. This setting has no effect if this site only has one referral type.</p>
      For example, consider a scenario that a user first visits with a referral link of type "Consultant" then later revisits with referral link of type "Partner".<br/>
      Cookie will be reassigned with "Partner" referral type if the checkbox is enabled otherwise it won’t get reassigned to new referral type.'),
    );

    $form['reserved_referral_ids'] = array(
      '#type' => 'textarea',
      '#title' => t('Reserved referral IDs'),
      '#default_value' => $config->get('reserved_referral_ids'),
      '#description' => t('Enter one or referral IDs to be reserved, which users cannot use in their referral ID fields. Enter one in each line.'),
    );

    $form['referrer_profile_field_label'] = [
      '#type' => 'textfield',
      '#title' => t('Label to be used for the Referrer field in user profile'),
      '#default_value' => $config->get('referrer_profile_field_label'),
      // '#description' => t(''),
    ];

    // Submit button.
    $form['actions'] = ['#type' => 'actions'];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('user_referral.settings');
    $config->set('allow_to_change_referral_type', $form_state->getValue('allow_to_change_referral_type'));
    $config->set('reserved_referral_ids', $form_state->getValue('reserved_referral_ids'));
    $config->set('referrer_profile_field_label', $form_state->getValue('referrer_profile_field_label'));
    $config->save();

    parent::submitForm($form, $form_state);
  }

}
