<?php

namespace Drupal\user_referral\Plugin\Derivative;

use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\user_referral\Entity\UserReferralType;

/**
 * Provides entity field block definitions for every field.
 *
 * @internal
 *   Plugin derivers are internal.
 */
class ReferralLinkDeriver extends DeriverBase implements ContainerDeriverInterface {

  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static();
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition) {
    $user_referral_types = UserReferralType::loadMultiple();
    foreach ($user_referral_types as $type_id => $referral_type) {
      $derivative = $base_plugin_definition;
      $derivative['label'] = t('@type referral link', ['@type' => $referral_type->label()]);
      $derivative_id = 'user_referral_link' . PluginBase::DERIVATIVE_SEPARATOR . $type_id;
      $derivative['id'] = $derivative_id;
      $this->derivatives[$derivative_id] = $derivative;
    }
    return $this->derivatives;
  }

}
