<?php

namespace Drupal\user_referral;

use Drupal\user\Entity\User;

/**
 * Class to wrap common functions of this module.
 */
class UserReferral {

  public static function createReferralEntry($entry) {
    if (is_object($entry)) {
      $entry = (array) $entry;
    }

    if (empty($entry['type'])) {
      $entry['type'] = 'default';
    }
    if (empty($entry['created'])) {
      $entry['created'] = time();
    }
    if (empty($entry['http_referer'])) {
      $entry['http_referer'] = $_SERVER['HTTP_REFERER'];
    }
    if (!isset($entry['default'])) {
      // Mark it as default if not specifically marked.
      $entry['default'] = 1;
    }
    if ($entry['default']) {
      // Make all other referrer entries, if any, non-default as only one can be marked as default.
      $num_updated = \Drupal::database()->update('user_referral')
        ->fields([
          'default' => 0,
        ])
        ->condition('uid', $entry['uid'])
        ->execute();
    }
    $result = \Drupal::database()->insert('user_referral')
    ->fields($entry)
    ->execute();
  }

  public static function getReferrer($account) {
    $database = \Drupal::database();
    $referrer_uid = $database->query("SELECT referrer_uid FROM {user_referral} WHERE `uid` = :user_id", array(':user_id' => $account->id()))
      ->fetchField();
    if ($referrer_uid) {
      return User::load($referrer_uid);
    }
  }

  /**
   * Get default referral entry for the user account.
   */
  public static function getReferralEntry($account) {
    if (is_object($account)) {
      $uid = $account->id();
    }
    else {
      $uid = $account;
    }
    $database = \Drupal::database();
    return $database->query("SELECT * FROM {user_referral} WHERE `uid` = :user_id AND `default` = :default", [':user_id' => $uid, ':default' => TRUE])->fetchObject();
  }
}
