<?php

namespace Drupal\user_referral;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\user_referral\Entity\UserReferralType;

/**
 * Provides dynamic permissions for different user referral types.
 */
class UserReferralPermissions {

  use StringTranslationTrait;

  /**
   * Returns an array of user referral type permissions.
   *
   * @return array
   *   The user referral type permissions.
   *   @see \Drupal\user\PermissionHandlerInterface::getPermissions()
   */
  public function userReferralTypePermissions() {
    $perms = [];
    // Generate node permissions for all user referral types.
    foreach (UserReferralType::loadMultiple() as $type) {
      $perms += $this->buildPermissions($type);
    }

    return $perms;
  }

  /**
   * Returns a list of permissions for a given user referral type.
   *
   * @param \Drupal\user_referral\Entity\UserReferralType $type
   *   The user referral type.
   *
   * @return array
   *   An associative array of permission names and descriptions.
   */
  protected function buildPermissions(UserReferralType $type) {
    $type_id = $type->id();
    $type_params = ['%type_name' => $type->label()];

    return [
      "view $type_id user referral links" => [
        'title' => $this->t('%type_name: View referral links', $type_params),
        'description' => $this->t('Roles with this permission are allowed to view the %type_name type referral link in user profile pages.', $type_params),
      ],
    ];
  }

}
