<?php

namespace Drupal\user_referral;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the user referral type entity type.
 *
 * @see \Drupal\user_referral\Entity\UserReferralType
 */
class UserReferralTypeAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'access content');

      case 'delete':
        $num_entries = \Drupal::database()->select('user_referral', 'ur')
          ->fields('ur', ['id'])
          ->condition('type', $entity->id())
          ->countQuery()->execute()->fetchField();
        if ($num_entries) {
          // Do not allow to delete referral type if associated referral entires are existing.
          return AccessResult::forbidden()->addCacheableDependency($entity);
        }
        else {
          return parent::checkAccess($entity, $operation, $account)->addCacheableDependency($entity);
        }
        break;

      default:
        return parent::checkAccess($entity, $operation, $account);

    }
  }

}
