<?php

namespace Drupal\user_referral;

use Drupal\Core\Config\Entity\DraggableListBuilder;
use Drupal\Core\Url;
use Drupal\Core\Entity\EntityInterface;

/**
 * Defines a class to build a listing of user referral type entities.
 *
 * @see \Drupal\user_referral\Entity\UserReferralType
 */
class UserReferralTypeListBuilder extends DraggableListBuilder {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'user_referral_types_admin__form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['label'] = t('Name');
    $header['description'] = [
      'data' => t('Description'),
      // 'class' => [RESPONSIVE_PRIORITY_MEDIUM],
    ];
    return $header + parent::buildHeader();
  }

  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    $row['label'] = $entity->label();
    $row['description']['data'] = ['#markup' => $entity->getDescription()];
    return $row + parent::buildRow($entity);
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultOperations(EntityInterface $entity) {
    $operations = parent::getDefaultOperations($entity);
    // Place the edit operation after the operations added by field_ui.module
    // which have the weights 15, 20, 25.
    if (isset($operations['edit'])) {
      $operations['edit']['weight'] = 30;
    }
    return $operations;
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    $build = parent::render();
    $build['help'] = [
      '#markup' => '<p>' . $this->t('Global settings affecting all referral types and links can be found at <a href=":settings_page" title="User Referral Settings">User Referral Settings</a> page.', [':settings_page' => Url::fromRoute('user_referral.settings')->toString()]) . '</p>',
      '#weight' => -1,
    ];
    $build['table']['#empty'] = $this->t('No user referral types available. <a href=":link">Add user referral type</a>.', [
        ':link' => Url::fromRoute('user_referral.type_add')->toString(),
      ]);
    return $build;
  }

}
