<?php

namespace Drupal\Tests\user_referral\Traits;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\field\Entity\FieldStorageConfig;
use Drupal\field\Entity\FieldConfig;

/**
 * Provides methods to create user referral type from given values.
 *
 * This trait is meant to be used only by test classes.
 */
trait ReferralIdFieldTrait {

  /**
   * Creates a referral ID field.
   *
   * @param string $field_name
   *   Optional field name
   *
   * @return string
   *   Field name.
   */
  protected function createReferralIDField($field_name = NULL) {
    if (empty($field_name)) {
      $field_name = mb_strtolower($this->randomMachineName());
    }
    $type = 'referral_id';
    $widget_type = 'referral_id_textfield';

    $field_storage = FieldStorageConfig::create([
      'field_name' => $field_name,
      'entity_type' => 'user',
      'type' => $type,
      'settings' => ['max_length' => 255, 'space_allowed' => FALSE],
    ]);
    
    $field_storage_saved = $field_storage->save();
    $this->assertSame($field_storage_saved, SAVED_NEW, (new FormattableMarkup('Created new field storage for Referral ID field %field.', ['%type' => $field_name]))->__toString());

    $this->field = FieldConfig::create([
      'field_storage' => $field_storage,
      'bundle' => 'user',
      'description' => 'Description for ' . $field_name,
      'required' => TRUE,
    ]);
    $field_saved = $this->field->save();

    $this->assertSame($field_saved, SAVED_NEW, (new FormattableMarkup('Created new Referral ID field %field.', ['%type' => $field_name]))->__toString());

    return $field_name;
  }

}
