<?php

/**
 * @file
 * Builds placeholder replacement tokens for user referral related data.
 */

use Drupal\Core\Render\BubbleableMetadata;
use Drupal\user_referral\Entity\UserReferralType;

/**
 * Implements hook_token_info().
 */
function user_referral_token_info() {
  $types = [
    'user_referral_type' => [
      'name' => t('User referral type'),
      'description' => t('Tokens related to individual user referral type items.'),
      'needs-data' => 'user_referral_type',
    ],
  ];

  // Core tokens for user referral type.
  $user_referral_type['type'] = [
    'name' => t("Machine name"),
    'description' => t('The unique ID of the user referral type item.'),
  ];
  $user_referral_type['name'] = [
    'name' => t("Name"),
    'description' => t("The human friendly name of the user referral type item."),
  ];

  $user_referral_type['referral_field_value'] = [
    'name' => t("Referral field value"),
    'description' => t("Referral field value from the user."),
  ];

  return [
    'types' => $types,
    'tokens' => ['user_referral_type' => $user_referral_type],
  ];
}

/**
 * Implements hook_tokens().
 */
function user_referral_tokens($type, $tokens, array $data, array $options, BubbleableMetadata $bubbleable_metadata) {
  $token_service = \Drupal::token();
  $replacements = [];

  if ($type == 'user_referral_type' && !empty($data['user_referral_type'])) {
    /** @var \Drupal\user_referral\UserReferralTypeInterface; $user_referral_type */
    $user_referral_type = $data['user_referral_type'];

    foreach ($tokens as $name => $original) {
      switch ($name) {
        // Simple key values on the node.
        case 'type':
          $replacements[$original] = $user_referral_type->id();
          break;

        case 'name':
          $replacements[$original] = $user_referral_type->label();
          break;

        case 'referral_field_value':
          if ($data['user']) {
            $account = $data['user'];
            $referral_field_item = $account->get($user_referral_type->getReferralField())->first();
            if (!empty($referral_field_item)) {
              $referral_id = $referral_field_item->getValue()['value'];
              $replacements[$original] = $referral_id;
            }
          }
      }
    }
  }

  return $replacements;
}
